#
# spec file for package octave
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define apiver  v53
# Required for RC builds, in this case version contains ~rc, src_ver -rc
%define pkg_ver 5.2.0
%define src_ver %{pkg_ver}

# Use native graphics or gnuplot
%bcond_without native_graphics

# Build GUI
%bcond_without gui

# JIT compilation
%bcond_with jit

# JAVA support
%bcond_without java

# Image processing library
# Default variant - GraphicsMagick
%bcond_with imagemagick

# Sound IO
%bcond_without sound

# Allow building without openBLAS, e.g. for architectures
# like RISC-V where openBLAS is not available
%bcond_without openblas

%if %{with openblas}
%define blas_library openblas
%else
%define blas_library blas
%endif

Name:           octave
Version:        %{pkg_ver}
Release:        lp152.2.4
Summary:        A High Level Programming Language
License:        GPL-3.0-or-later
Group:          Productivity/Scientific/Math
URL:            http://www.octave.org/
Source:         https://ftp.gnu.org/gnu/octave/%{name}-%{src_ver}.tar.lz
Source2:        octave.pc.in
Source3:        octave.macros
# PATCH-FIX-OPENSUSE
Patch0:         octave_tools_pie.patch
# PATCH-FIX-UPSTREAM - https://savannah.gnu.org/bugs/?54607
Patch1:         0001-Disable-signal-handler-thread-avoid-duplicate-signal.patch
BuildRequires:  arpack-ng-devel
# Required for Patch0
BuildRequires:  autoconf
BuildRequires:  automake
BuildRequires:  libtool
#
BuildRequires:  %{blas_library}-devel
BuildRequires:  bison
BuildRequires:  dejagnu
BuildRequires:  fftw3-threads-devel
BuildRequires:  flex
BuildRequires:  gcc-c++
BuildRequires:  gcc-fortran
BuildRequires:  glpk-devel
BuildRequires:  gmp-devel
BuildRequires:  gperf
BuildRequires:  hdf5-devel
BuildRequires:  lapack-devel
# required for help/doc called from the tests
BuildRequires:  makeinfo
BuildRequires:  memory-constraints
%if %{with imagemagick}
BuildRequires:  pkgconfig(ImageMagick++)
%else
BuildRequires:  pkgconfig(GraphicsMagick++)
%endif
BuildRequires:  lzip
BuildRequires:  pcre-devel
BuildRequires:  pkg-config
BuildRequires:  qhull-devel
BuildRequires:  qrupdate-devel
BuildRequires:  readline-devel
BuildRequires:  suitesparse-devel
BuildRequires:  termcap
BuildRequires:  pkgconfig(libcurl)
BuildRequires:  pkgconfig(zlib)
# GUI build requires
%if %{with gui}
BuildRequires:  desktop-file-utils
BuildRequires:  hicolor-icon-theme
BuildRequires:  libqscintilla_qt5-devel
BuildRequires:  libqt5-linguist
BuildRequires:  libqt5-qttools
BuildRequires:  update-desktop-files
BuildRequires:  pkgconfig(Qt5Core)
BuildRequires:  pkgconfig(Qt5Gui)
BuildRequires:  pkgconfig(Qt5Help)
BuildRequires:  pkgconfig(Qt5Network)
BuildRequires:  pkgconfig(Qt5OpenGL)
BuildRequires:  pkgconfig(Qt5PrintSupport)
# testing
BuildRequires:  xorg-x11-Xvfb
# boo#1095605
Requires:       libQt5Sql5-sqlite
Obsoletes:      octave-gui < 4.0
Provides:       octave-gui = %{version}
%endif
# Sound IO build requires
%if %{with sound}
BuildRequires:  pkgconfig(alsa)
BuildRequires:  pkgconfig(portaudio-2.0)
BuildRequires:  pkgconfig(sndfile)
%endif
# JAVA functions build requires
%if %{with java}
BuildRequires:  java-devel
%endif
# JIT build requires
%if %{with jit}
BuildRequires:  llvm-devel
%endif
# Native graphics build requires
%if %{with native_graphics}
BuildRequires:  Mesa-devel
BuildRequires:  fltk-devel
BuildRequires:  gl2ps-devel
BuildRequires:  pkgconfig(fontconfig)
BuildRequires:  pkgconfig(freetype2)
BuildRequires:  pkgconfig(glu)
%else
Requires:       gnuplot
%endif
# Tests build requires
BuildRequires:  unzip
BuildRequires:  zip
Requires:       octave-cli = %{version}
Requires(pre):  update-alternatives

%description
Octave is a high level programming language. It is designed for the
solution of numeric problems.
%if %{with gui}

This package contains the graphical user interface.
%endif

%package        cli
Summary:        Command-line user interface for Octave
Group:          Productivity/Scientific/Math
Requires:       makeinfo
Requires(pre):  update-alternatives
%if %{with native_graphics}
Recommends:     epstool
Recommends:     pstoedit
# transfig requires texlive installation now
# Recommends:     transfig
%endif
Recommends:     octave-doc = %{version}

%description    cli
Octave is a high level programming language. It is designed for the
solution of numeric problems.

This package contains the command-line user interface.

%package        devel
Summary:        Development files for Octave
Group:          Development/Languages/Other
Requires:       %{blas_library}-devel
Requires:       %{name}-cli = %{version}
Requires:       fftw3-devel
Requires:       fftw3-threads-devel
Requires:       gcc-c++
Requires:       gcc-fortran
Requires:       hdf5-devel
Requires:       make

%description    devel
Octave is a high level programming language. It is designed for the
solution of numeric problems.

This package contains all necessary include files and libraries needed
to develop applications using Octave.

%package        doc
Summary:        Documentation for Octave
Group:          Documentation/Other
BuildArch:      noarch

%description    doc
Octave is a high level programming language. It is designed for the
solution of numeric problems.

This package contains documentation for Octave.

%prep
%setup -q -n %{name}-%{src_ver}
%patch0 -p1
%patch1 -p1

# define octave_blas macros
sed -i 's/OCTAVE_BLAS_LIBRARY_NAME/%{blas_library}/g' %{SOURCE3}

%build
%limit_build -m 700

# rebuild makefiles after Patch0
autoreconf -i -s -f
%if 0%{?suse_version} > 1500
export QCOLLECTIONGENERATOR=qhelpgenerator-qt5
%endif
%configure \
  --libexecdir=%{_libdir} \
  %{?with_gui: --with-qt} \
  %{!?with_gui: --without-qt} \
  %{?with_jit: --enable-jit} \
  %{!?with_java: --disable-java} \
  --with-blas=%{blas_library} \
  --disable-docs \
  --enable-openmp

make %{?_smp_mflags}

# .pc file
cp %{SOURCE2} octave.pc
sed -i 's:@VERSION@:%{src_ver}:' octave.pc
sed -i 's:@LIB@:%{_lib}:' octave.pc

%install
%make_install
# see bnc#557340
mkdir -p %{buildroot}/%{_sysconfdir}/ld.so.conf.d
echo %{_libdir}/%{name}/%{src_ver} > %{buildroot}/%{_sysconfdir}/ld.so.conf.d/%{name}.conf
rm %{buildroot}/%{_libdir}/%{name}/%{src_ver}/*.la
# local rc file into /etc
mkdir %{buildroot}/%{_sysconfdir}/%{name}
mv %{buildroot}/%{_datadir}/%{name}/site/m/startup/octaverc %{buildroot}/%{_sysconfdir}/%{name}
ln -s %{_sysconfdir}/%{name}/octaverc %{buildroot}/%{_datadir}/%{name}/site/m/startup/octaverc
#
mkdir -p %{buildroot}/%{_libdir}/%{name}/packages
mkdir -p %{buildroot}/%{_datadir}/%{name}/packages
# Documentation
install -Dm 644 -t %{buildroot}%{_mandir}/man1/ doc/*/*.1
install -Dm 644 -t %{buildroot}%{_infodir} doc/*/*.info doc/*/*.info-*
# .pc file
mkdir -p %{buildroot}/%{_libdir}/pkgconfig
cp octave.pc %{buildroot}/%{_libdir}/pkgconfig
# Remove icons with huge size, we have scalable SVGs
rm -rf %{buildroot}/%{_datadir}/icons/hicolor/1024x1024
# gui related fixes
%if %{without gui}
rm -rf %{buildroot}/%{_datadir}/icons/hicolor/
rm -rf %{buildroot}/%{_datadir}/metainfo/
rm -rf %{buildroot}/%{_datadir}/applications/
%endif
# rpm macros
install -Dm 644 %{SOURCE3} %{buildroot}%{_sysconfdir}/rpm/macros.octave
# increase stack size set by the JVM, affects the whole octave process
echo "-Xss8m" >  %{buildroot}/%{_datadir}/%{name}/%{src_ver}/m/java/java.opts

%check
# Increase stack limits. OpenBLAS tests are run after some JVM test, and OpenBLAS
# dgetrf is quite memory hungry, see https://github.com/xianyi/OpenBLAS/issues/246

%define         X_display         ":98"
export DISPLAY=%{X_display}
Xvfb %{X_display} >& Xvfb.log &
trap "kill $! || true" EXIT
sleep 10

echo "-Xss8m" >  scripts/java/java.opts
make check

%post -p /sbin/ldconfig

%postun -p /sbin/ldconfig

%post cli
/sbin/ldconfig
%install_info --info-dir=%{_infodir} %{_infodir}/octave.info.gz

%postun cli
/sbin/ldconfig
%install_info_delete --info-dir=%{_infodir} %{_infodir}/octave.info.gz

%files
%license COPYING
%doc AUTHORS BUGS NEWS
%doc README ChangeLog
%if %{with gui}
%{_libdir}/%{name}/%{src_ver}/exec/*-*-linux-gnu*/octave-gui
%{_libdir}/%{name}/%{src_ver}/exec/*-*-linux-gnu*/octave-svgconvert
%{_libdir}/%{name}/%{src_ver}/liboctgui.so.*
%{_datadir}/%{name}/%{src_ver}/locale/
%{_datadir}/metainfo/*.xml
%{_datadir}/applications/*.desktop
%{_datadir}/icons/hicolor/*/apps/octave.*
%endif

%files cli
%{_bindir}/octave
%{_bindir}/octave-%{src_ver}
%{_bindir}/octave-cli
%{_bindir}/octave-cli-%{src_ver}
%{_mandir}/man1/octave.1.gz
%{_mandir}/man1/octave-cli.1.gz
%{_bindir}/octave-config
%{_bindir}/octave-config-%{src_ver}
%{_mandir}/man1/octave-config.1.gz
%{_infodir}/*.gz
%config %{_sysconfdir}/ld.so.conf.d/%{name}.conf
%config(noreplace) %{_sysconfdir}/%{name}/octaverc
%dir %{_libdir}/%{name}
%dir %{_libdir}/%{name}/%{src_ver}
%dir %{_libdir}/%{name}/packages
%dir %{_datadir}/%{name}/packages
%dir %{_sysconfdir}/%{name}
%{_libdir}/%{name}/%{src_ver}/oct
%{_libdir}/%{name}/%{src_ver}/liboctave.so.*
%{_libdir}/%{name}/%{src_ver}/liboctinterp.so.*
%if %{with gui}
%dir %{_libdir}/%{name}/%{src_ver}/exec/
%dir %{_libdir}/%{name}/%{src_ver}/exec/*-*-linux-gnu*/
%exclude %{_datadir}/%{name}/%{src_ver}/locale/
%endif
%{_datadir}/octave/
%{_libdir}/%{name}/site

%files devel
%{_bindir}/mkoctfile
%{_bindir}/mkoctfile-%{src_ver}
%{_mandir}/man1/mkoctfile.1.gz
%{_includedir}/*
%{_libdir}/%{name}/%{src_ver}/lib*.so
%{_libdir}/%{name}/api-%{apiver}
%{_libdir}/pkgconfig/octave.pc
%{_libdir}/pkgconfig/octinterp.pc
%config %{_sysconfdir}/rpm/macros.octave

%files doc
%doc doc/interpreter/octave.pdf
%doc doc/liboctave/liboctave.pdf
%doc doc/refcard/refcard-a4.pdf
%doc doc/refcard/refcard-legal.pdf

%changelog
* Mon Feb 17 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Avoid stealing SIGCHLD from QProcess::waitForFinished, which
  causes the KDE file dialogs to hang up to the 30s default timeout.
  This only happens when a samba server is installed locally.
  Fixes https://savannah.gnu.org/bugs/?54607
  * 0001-Disable-signal-handler-thread-avoid-duplicate-signal.patch
- Add Xvfb build dependency for make check, several tests fail
  otherwise.
* Sun Feb 16 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Readd makeinfo to the build dependencies, called by octaves
  doc/help functions from the tests. Disable doc generation
  explicitly, otherwise it tries even without all tools present.
* Sun Feb  9 2020 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.2.0
  This version is a bug fixing release, for details see:
  https://www.gnu.org/software/octave/news/release/2020/01/31/octave-5.2.0-released.html
- Drop upstream patches:
  * octave-bug-55029-fix_pause_and_kbhit_with_glibc_2_28.patch
  * octave-bug-56533-Cursor_misplaced_when_entering_newline_in_editor_with_tabs_indentation-part1.patch
  * octave-bug-56533-Cursor_misplaced_when_entering_newline_in_editor_with_tabs_indentation-part2.patch
- Use documentation from upstream tarball, no need to rebuild locally.
- Cleanup spec file, remove conditionals for EOLed distributions.
* Wed Nov 27 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Fix octave_pkg_test in RPM octave.macros, unpack pkg tarball
  again, as the target directory is removed by 'pkg build'.
* Fri Jul  5 2019 UTC - Markus Ebner <hiwatari.seiji@gmail.com>
- Backport fix: Cursor misplaced when entering newline in editor with tabs indentation
  behavior (bug #56533)
  * Added octave-bug-56533-Cursor_misplaced_when_entering_newline_in_editor_with_tabs_indentation-part1.patch
  * Added octave-bug-56533-Cursor_misplaced_when_entering_newline_in_editor_with_tabs_indentation-part2.patch
* Mon May 13 2019 Duncan Mac-Vicar <dmacvicar@suse.de>
- Backport fix: pause and kbhit with glibc 2.28 end-of-file state
  behavior (bug #55029)
  * Added octave-bug-55029-fix_pause_and_kbhit_with_glibc_2_28.patch
* Mon Mar  4 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 5.1.0
  * Long list of changes: see
    https://www.gnu.org/software/octave/NEWS-5.1.html
    https://www.gnu.org/software/octave/news/release/2019/03/01/octave-5.1-released.html
- Rebase octave_tools_pie.patch
- Add conditional building with blas instead of openBLAS. Allows building
  for architectures like RISC-V where openBLAS is not available (and probably
  never will, RISC-V vector instructions do not fit the openBLAS model).
* Fri Feb 15 2019 Guillaume GARDET <guillaume.gardet@opensuse.org>
- Add %%limit_build to avoid build failures
* Thu Jan 10 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Only set -fpie for octave executables, as LDFLAGS is set as link flag
  in mkoctfile as default flags, leading to failing module builds.
  Add octave_tools_pie.patch
* Thu Jan  3 2019 Stefan Brüns <stefan.bruens@rwth-aachen.de>
- Update to version 4.4.1
  * Long list of changes: see
    https://www.gnu.org/software/octave/news/release/2018/08/09/octave-4.4.1-released.html
- Drop obsolete Fix-build-with-Qt-511.patch
- Fix build with Qt 5.12, use qhelpgenerator for qcollectiongenerator
- Stop messing with upstream appdata/desktop files
- Use %%bcond_with/%%bcond_without
- Fix unit tests by increasing JVM stack limit, see https://savannah.gnu.org/bugs/index.php?55395
* Fri Jun 22 2018 dmitry_r@opensuse.org
- Qt5 GUI package requires libQt5Sql5-sqlite [boo#1095605]
* Mon Jun  4 2018 christophe@krop.fr
- Add Fix-build-with-Qt-511.patch.
- Use %%license for license files
* Wed May 16 2018 dmitry_r@opensuse.org
- Update to version 4.4.0
  See https://www.gnu.org/software/octave/NEWS-4.4.html for details
- Drop octave-java-use-source-target-1_6.patch
- Drop SLE11 support (already broken)
- Drop update-alternatives usage
* Mon Mar 19 2018 badshah400@gmail.com
- Update to version 4.2.2:
  * Long list of changes: see
    https://www.gnu.org/software/octave/news/release/2018/03/13/octave-4.2.2-released.html
- Drop octave-also-check-for-qscintilla2_qt5.patch: incorporated
  upstream.
* Mon Oct  2 2017 badshah400@gmail.com
- Add octave-java-use-source-target-1_6.patch: Switch
  source/target to 1.6 from 1.3, to get octave building with java
  9 (for openSUSE > 1320); patch taken from upstream mercurial
  repository [https://savannah.gnu.org/bugs/?51803].
* Wed Aug 23 2017 dmitry_r@opensuse.org
- Fix octave-devel package requirements
- Add %%octave_blas macros
* Mon Aug 21 2017 dmitry_r@opensuse.org
- Move mkoctfile binary to octave-devel package
* Thu Aug 10 2017 dmitry_r@opensuse.org
- Reenable sparce matrix support
- Build with openBLAS library by default, except i*86 architectures
  due to tests failures
* Mon Jul 10 2017 badshah400@gmail.com
- Edit _constraints file to require at least 2GB physical memory,
  builds on 32-bit systems fail otherwise; see
  https://savannah.gnu.org/bugs/index.php?51436; fixes build
  failures on i586 for openSUSE > 1320.
- Drop suitesparse-devel BuildRequires; this pulls in openblas,
  which is not recommended by upstream. See comment #2 in
  https://savannah.gnu.org/bugs/index.php?51436.
* Mon Jun 26 2017 badshah400@gmail.com
- Add octave-also-check-for-qscintilla2_qt5.patch: When checking
  for the availibility of QT5 bindings for scintilla, also check
  for qscintilla2_qt5 (which is the shlib name used by openSUSE),
  otherwise this causes the in-built editor to be disabled; patch
  taken from upstream. Since patch modifies m4 files, regenerate
  configure before executing it (add BuildRequires on automake,
  autoconf and libtool). All changes applied conditionally only
  when building against Qt5.
* Tue Feb 28 2017 dmitry_r@opensuse.org
- Update to version 4.2.1
  * See icluded NEWS file for details
* Tue Nov 15 2016 dmitry_r@opensuse.org
- Update to version 4.2.0
  * See icluded NEWS file for details
* Thu Nov 10 2016 dmitry_r@opensuse.org
- Update to version 4.2.0-rc4
  * See icluded NEWS file for details
* Mon Oct 31 2016 dmitry_r@opensuse.org
- Update to version 4.2.0-rc3
  * See icluded NEWS file for details
  * Drop octave-gui-info-links.patch, octave-gui-utf8.patch
* Thu Oct 27 2016 dmitry_r@opensuse.org
- Fix Qt5-based GUI documentation links
  * octave-gui-info-links.patch
- Fix Qt4-based GUI text encoding [boo#1005431]
  * octave-gui-utf8.patch
* Wed Oct 19 2016 dmitry_r@opensuse.org
- Build Qt5-based GUI for openSUSE Tumbleweed
- Clean build requires
- Move pkg-config file to octave-devel package
* Tue Oct 18 2016 badshah400@gmail.com
- Run %%desktop_database_post(un) and %%icon_theme_cache_post(un)
  for %%post(un) to update the icon theme cache (required whenever
  application installs icons to the hicolor icon dir) and desktop
  database (required whenever application installs a .desktop
  file) when building with GUI enabled.
* Fri Sep 23 2016 dmitry_r@opensuse.org
- Update to version 4.2.0~rc2
  * See icluded NEWS file for details
- Drop obsolete ocatve-evalc.patch
* Sat Sep 17 2016 dmitry_r@opensuse.org
- Fix evalc crash
  * ocatve-evalc.patch
* Sun Sep 11 2016 dmitry_r@opensuse.org
- Update to version 4.2.0~rc1
  * See icluded NEWS file for details
- Drop obsolete octave-gcc6.patch
- Temporary set MALLOC_PERTURB_=0 for tests
* Fri Aug 26 2016 dmitry_r@opensuse.org
- Fix suse-alternative-link-missing [boo#994253]
* Fri Jul 29 2016 dmitry_r@opensuse.org
- Use original appdata file
- Fix SLE12 build
* Thu Jul 28 2016 badshah400@gmail.com
- Update to version 4.0.3:
  * Bug fix release, see
    http://www.gnu.org/software/octave/fixes-4-0-3.html for a full
    list of fixes.
- Add appdata file as source, and install it to
  /usr/share/appdata; this makes octave appear on appstores like
  gnome-software and KDE Discover.
- Rebase octave-gcc6.patch for current version.
* Sat Jun 18 2016 dmitry_r@opensuse.org
- Fix build with GCC6 [boo#985363]
  * octave-gcc6.patch
* Tue Jun  7 2016 dmitry_r@opensuse.org
- Update to version 4.0.2
  * Bugfix release
- Fix SLE12 config
- Use update-alternatives mechanism for octave binary
* Tue Mar 22 2016 dmitry_r@opensuse.org
- Update to version 4.0.1
  * Bugfix release
* Tue Feb 23 2016 ro@suse.de
- vendor is ibm on s390, not suse
* Fri Oct 23 2015 dvaleev@suse.com
- Add disk constraints. Some workers might have enabled build in
  tmpfs. Where the space is limited.
* Sun Sep 13 2015 dmitry_r@opensuse.org
- Fix desktop menu category
* Thu Jul 23 2015 dmitry_r@opensuse.org
- Add build config for openSUSE:42
* Fri May 29 2015 dmitry_r@opensuse.org
- Update to version 4.0.0
  * See icluded NEWS file for details
- Drop obsolete patches:
  * octave-3.8.0-llvm-3.4.patch
  * octave-suitesparse-4.4.patch
  * octave-unzip-info-in-gui.patch
- Add RPM macros to octave-devel package
  * octave.macros
* Mon Feb 23 2015 dmitry_r@opensuse.org
- Fix unzipping compressed info files when running the gui [boo#918942]
  * octave-unzip-info-in-gui.patch
- Disable JIT compilation by default
- Set build settings for SLE11
* Wed Nov 12 2014 dmitry_r@opensuse.org
- Set build settings for SLE12
* Fri Oct 31 2014 dmitry_r@opensuse.org
- Fix build with latest SuiteSparse library
  * octave-suitesparse-4.4.patch
- Restore SuiteSparse linking hack for openSUSE <= 13.1
* Sat Oct 11 2014 dmueller@suse.com
- fix filelist on armv6/7hl: triplet is gnueabi, not gnu
* Fri Aug 22 2014 dmitry_r@opensuse.org
- Move GUI localization files to octave-gui package
* Fri Aug 15 2014 dmitry_r@opensuse.org
- Fix runtime dependencies: makeinfo instead of texinfo [bnc#892123]
* Wed Aug 13 2014 dmitry_r@opensuse.org
- Update to version 3.8.2
  * Bugfix release, see included ChangeLog file for details
- Drop suitesparse linking hack [bnc#883683]
* Thu Jun 19 2014 dmitry_r@opensuse.org
- Build with FFTW3 multi-threading support
* Tue Apr 22 2014 dmitry_r@opensuse.org
- Enable OpenMP support
* Fri Mar  7 2014 dmitry_r@opensuse.org
- Update to version 3.8.1
  * Bugfix release, see included ChangeLog file for details
  * removed obsolete octave-3.8.0-gzip-compressed-info.patch
- Disable JIT support for non-x86 architectures
* Sat Feb  1 2014 dmitry_r@opensuse.org
- Fix build with LLVM-3.4
  * octave-3.8.0-llvm-3.4.patch
* Thu Jan  2 2014 dmitry_r@opensuse.org
- Fix loading gzip-compressed info files [bnc#857130]
  * octave-3.8.0-gzip-compressed-info.patch
* Mon Dec 30 2013 dmitry_r@opensuse.org
- Add octave-gui as recommended dependence
- Build with jit support
* Sat Dec 28 2013 dmitry_r@opensuse.org
- Update to version 3.8.0
  * See included NEWS and ChangeLog files for details
- Removed obsolete octave-gcc48-mex_remove_externc.patch
* Sun Jul 28 2013 klaussfreire@gmail.com
- Added octave-gcc48-mex_remove_externc, fixes an issue when
  building packages that include mex.h in gcc 4.8
* Wed May  1 2013 dmitry_r@opensuse.org
- Cleanup recommended packages
* Sat Mar 30 2013 dmitry_r@opensuse.org
- Move documentation to octave-doc package
* Thu Mar 14 2013 pgajdos@suse.com
- minor spec file adjustment
* Fri Mar  8 2013 dmitry_r@opensuse.org
- Fix native graphics support for openSUSE 12.3 [bnc#808530]
* Thu Feb 28 2013 dmitry_r@opensuse.org
- Update to version 3.6.4
  * See included ChangeLog file for details
- Enable post build tests
- Enable paralell build
* Thu Feb  7 2013 dmitry_r@opensuse.org
- Enable native graphics
* Wed Dec 12 2012 pgajdos@suse.com
- install octave.pc file [bnc#793682]
  + source octave.pc.in
* Mon Dec  3 2012 pgajdos@suse.com
- local rc file into /etc (Dieter Jurzitza) [bnc#792507]
* Tue Oct 30 2012 dieter.jurzitza@t-online.de
- add makeinfo to BuildRequires
* Fri Oct 26 2012 badshah400@gmail.com
- Update to version 3.6.3:
  + Too many bug-fixes to list, see installed CHANGELOG file for a
    list.
- Drop octave-gets.patch, incorporated upstream.
* Tue Sep 18 2012 idonmez@suse.com
- Add BuildRequires on texinfo (instead of makeinfo) and texlive-dvips
* Tue Sep 11 2012 pgajdos@suse.com
- fix /etc/ld.so.conf.d/octave.conf [bnc#779072]
* Sat Sep  8 2012 idonmez@suse.com
- Add explicit build dependency on makeinfo
* Tue Aug 21 2012 dmitry@roshchin.org
- Change packages directories owner
* Sun Aug 19 2012 scorot@free.fr
- fix umfpack and cholmod linking according to recent suitesparse
  update
- enable arpack support
* Sun Jul 29 2012 aj@suse.de
- Fix build with missing gets declaration (glibc 2.16)
* Fri Jun  1 2012 pgajdos@suse.com
- updated to 3.6.2:
  * fix bad two-arg call of randperm
  * perform convolution properly independently of matrix orientation
  * implement proper op() indexing for diagonal matrices
  * poissrnd should return zero when lambda = 0
  * ensure isargout is not sticky
  * etc., see ChangeLog
* Fri May 11 2012 scorot@free.fr
- remove conditional BuildRequires for blas and lapack since
  recent lapack now build correctly for all suse version
- recommends blas -> blas-devel
* Mon Apr 30 2012 cfarrell@suse.com
- license update: GPL-3.0+
  See COPYING - octave is GPL-3.0+ licensed, not GPL-2.0+
* Mon Apr 16 2012 badshah400@gmail.com
- Spec file cleanup: remove Authors from description, remove
  conditionals referring to obsolete suse_versions.
* Fri Apr 13 2012 badshah400@gmail.com
- Modify BuildRequires to match recent name changes of lapack and
  blas in project.
* Tue Feb 28 2012 pgajdos@suse.com
- build against fltk (native graphics)
- build against arpack
* Mon Feb 27 2012 pgajdos@suse.com
- updated to 3.6.1:
  * removed qhull.patch
* Mon Jan 30 2012 pgajdos@suse.com
- build against 2012.1
* Mon Jan  9 2012 pgajdos@suse.com
- thanks to Martin Helm: remove octave-umfpack.patch and
  use --with-umfpack configure switch instead
* Thu Dec  1 2011 pgajdos@suse.com
- again build against hdf5
* Tue Nov 15 2011 pgajdos@suse.com
- don't build against hdf5 for now, hdf5 is not building against
  12.1 and Factory
* Mon Oct 24 2011 pgajdos@suse.com
- updated to 3.4.3:
  * removed unneeded tar-cond.patch
* Wed Oct 12 2011 pgajdos@suse.com
- build against Mesa-devel and fltk-devel conditional, use gnuplot
  rather
* Fri Oct  7 2011 pgajdos@suse.com
- fixed tar(), see
  http://trac.imagemagick.org/changeset/5359
  * tar-cond.patch
* Wed Oct  5 2011 pgajdos@suse.com
- build against Mesa-devel, fltk-devel -> native graphics
- really build against cxsparse
- build against qrupdate
* Mon Oct  3 2011 pgajdos@suse.com
- really build against umfpack
* Sat Oct  1 2011 pgajdos@suse.com
- build against suitesparse-devel instead of umfpack-devel (umfpack
  is part of suitesparse package from now on)
* Tue Sep 20 2011 pgajdos@suse.com
- build against qhull
* Tue Aug 16 2011 pgajdos@novell.com
- linked against umfpack (thanks to Christof Kauffman for
  notification)
* Tue Jul 26 2011 pgajdos@novell.com
- updated to 3.4.2
* Thu Jun 16 2011 pgajdos@novell.com
- updated to 3.4.1
  * no-return-in-nonvoid.patch
* Sun May 29 2011 werner.ho@gmx.de
- fixed hdf5-devel package name
* Tue Feb 15 2011 pgajdos@suse.cz
- updated to 3.4.0
* Thu Jan 13 2011 pgajdos@suse.cz
- downgrade back to 3.2.4 stable
* Fri Jan  7 2011 pgajdos@suse.cz
- build against GraphicsMagick
- updated to 3.3.54
* Mon Feb 15 2010 pgajdos@suse.cz
- updated to 3.2.4 (see NEWS and ChangeLog)
* Mon Nov 23 2009 pgajdos@suse.cz
- better handling of library path in the specfile [bnc#557340]
* Wed Nov 11 2009 pgajdos@suse.cz
- updated to 3.2.3 (see NEWS and ChangeLog)
- fixed [bnc#552978]
* Thu Aug  6 2009 pgajdos@suse.cz
- updated to 3.2.2
  - bugfix release
* Mon Jun 22 2009 pgajdos@suse.cz
- updated to version 3.2.0 (see NEWS)
* Tue Apr 14 2009 pgajdos@suse.cz
- updated to 3.0.5:
  * last bug-fixing-release
* Thu Mar 19 2009 pgajdos@suse.cz
- removed octave-3.0.3.patch completely [bnc#480571]
* Wed Mar 18 2009 pgajdos@suse.cz
- cstring -> string.h in patch [bnc#480571]
* Thu Feb 26 2009 pgajdos@suse.cz
- added texinfo to the Requires [bnc#285607]
* Mon Jan 26 2009 pgajdos@suse.cz
- added some packages to Recommends [bnc#468395]
* Tue Jan 13 2009 pgajdos@suse.cz
- updated to 3.0.3:
  * next bug-fixing release
* Mon Sep  8 2008 pgajdos@suse.cz
- updated to 3.0.2:
  * next bug-fixing release
* Wed Jul  2 2008 pgajdos@suse.cz
- build againist hdf5 1.8.1 -- using compatibility -DH5_USE_16_API
* Mon Jun 23 2008 pgajdos@suse.cz
- new version 3.0.1:
  * bug-fixing release
* Tue Mar 25 2008 pgajdos@suse.cz
- new version 3.0.0 moved from OBS, project science
  * improved compatibility with Matlab (tm)
  * bugfixes
- newly linked optional libraries: curl, hdf5, glpk
* Mon Nov 19 2007 pgajdos@suse.cz
- %%{_datadir}/octave/site/m/startup/octaverc linked to /etc/octave
  and marked as %%config(noreplace)
- several minor spec file cleanups
* Wed Oct 17 2007 pgajdos@suse.cz
- fixed build with new gcc -- added missing includes
  * missing-includes.patch
* Wed Jul 25 2007 pgajdos@suse.cz
- supressed paralell building which fails at least on some
  architectures
* Wed Jul 11 2007 pgajdos@suse.cz
- updated to 2.9.12 and removed randlib [#279883]
- without-randlib.patch
* Thu Jun 21 2007 pgajdos@suse.cz
- added texinfo to Requires
* Fri May 25 2007 pgajdos@suse.cz
- made subpackage octave-devel
* Sat Apr 21 2007 aj@suse.de
- Use texlive.
* Thu Jun 22 2006 ro@suse.de
- remove selfprovides
* Wed May 24 2006 anicka@suse.cz
- update to 2.1.73
  - bugfix release
* Mon Feb 13 2006 anicka@suse.cz
- require gcc-fortran (fixes #150047)
* Wed Feb  1 2006 anicka@suse.cz
- add -Os to FFLAGS (fixes #136787)
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Sat Jan 14 2006 kukuk@suse.de
- Add gmp-devel to nfb
* Thu Jan  5 2006 anicka@suse.cz
- update to 2.1.72
* Mon Nov 14 2005 anicka@suse.cz
- fix build (gcc 4.1)
* Tue Nov  1 2005 anicka@suse.cz
- fix build (move code around in CMatrix.cc)
* Tue Jun 28 2005 anicka@suse.cz
- update to 2.1.71
* Wed May 11 2005 ro@suse.de
- fix build with gcc4
* Mon Apr 18 2005 mcihar@suse.de
- GNU Fortran 77 compiler now requires gmp, let's add it
- still doesn't compile, because GCC: TODO: Functions with alternate entry points
* Tue Dec 21 2004 mcihar@suse.cz
- update to 2.1.64
- do not include info pages, as they are out of date
- string patching was not needed for long time, so drop the patch
* Thu Nov 11 2004 ro@suse.de
- fixed file list
* Wed Aug  4 2004 mcihar@suse.cz
- update to 2.1.57
* Fri Mar  5 2004 mcihar@suse.cz
- really compile with -fno-strict-aliasing
- doesn't need f2c at all
* Fri Mar  5 2004 mcihar@suse.cz
- update to 2.1.55
- fix info pages installation
- add some docs
- use -fno-strict-aliasing
* Fri Jan  9 2004 adrian@suse.de
- add %%run_ldconfig
- use RPM_OPT_FLAGS
* Fri Aug 29 2003 mcihar@suse.cz
- info pages should not be executable
* Wed Aug 13 2003 ro@suse.de
- fix info page installation again (thanks to DJurzitza)
* Wed Jul 30 2003 ro@suse.de
- install more info pages
* Thu Jun 26 2003 ro@suse.de
- remove traces of buildroot from installed files
* Wed Jun 11 2003 ltinkl@suse.cz
- updated sources to version 2.1.49
* Thu Apr 24 2003 ro@suse.de
- fix install_info --delete call and move from preun to postun
* Mon Mar  3 2003 ro@suse.de
- added info dir entries
* Tue Feb 25 2003 mcihar@suse.cz
- removed -mminimal-toc as it is now part of RPM_OPT_FLAGS for ppc64
- added gnuplot to requires
* Mon Feb 10 2003 mcihar@suse.cz
- used %%install_info macro (fixes bug #23443)
* Wed Feb  5 2003 mcihar@suse.cz
- removed RPM_OPT_FLAGS="$RPM_OPT_FLAGS -mminimal-toc" for ppc64
  (fixes bug #23266)
- updated to 2.1.44
* Fri Nov 22 2002 mcihar@suse.cz
- updated to 2.1.40, mostly only configure and automake fixes, it
  also fixes sstream and some other smaller issues with gcc 3.3
- fixed multiline string
* Tue Aug  6 2002 mcihar@suse.cz
- updated to 2.1.36
* Sat Jun 29 2002 olh@suse.de
- build with -mminimal-toc on ppc64, use RPM_OPT_FLAGS for CFLAGS
* Tue May 21 2002 ro@suse.de
- call suse_update_config also for kpathsea subdir
* Wed May  8 2002 ro@suse.de
- fix for latest gcc-snapshot
* Fri Apr 19 2002 coolo@suse.de
- updating to octave 2.1.35 as octave 2.0.1[67] were hopeless
  with gcc 3.1 (gave up after 2 days of work)
* Tue May  8 2001 mfabian@suse.de
- bzip2 sources
* Fri May  5 2000 bubnikv@suse.cz
- added buildroot
- /usr/execlib/octave moved to /usr/lib/octave according to FHS 2.1
* Mon Feb 21 2000 ro@suse.de
- update to 2.0.16
* Tue Jan 25 2000 ro@suse.de
- update to 2.0.15
- man,info to /usr/share using macro
* Mon Sep 13 1999 bs@suse.de
- ran old prepare_spec on spec file to switch to new prepare_spec.
* Tue Jul 13 1999 ro@suse.de
- update to 2.0.14
* Thu May 20 1999 ro@suse.de
- use CFLAGS="-D_GNU_SOURCE"
* Mon Nov 23 1998 ro@suse.de
- update to 2.0.13 / builds with glibc
* Tue Oct  6 1998 ro@suse.de
- BETA: added f2c to neededforbuild
* Wed Jan 28 1998 ro@suse.de
- removed libhistory.so & libreadline.so as well and link static
  to these
* Mon Nov 17 1997 bs@suse.de
- removed libhistory.a & libreadline.a from file list.
* Wed Nov 12 1997 ro@suse.de
- minor changes in specfile
  setting host to ARCH-suse-linux
* Mon Nov 10 1997 ro@suse.de
- new version 2.0.9
* Tue Oct  7 1997 ro@suse.de
- prepared spec file
- added README-GCC-2.7.? patches
